summaryrefslogtreecommitdiff
path: root/perl.h
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>1997-11-19 22:10:51 -0800
committerMalcolm Beattie <mbeattie@sable.ox.ac.uk>1997-11-25 14:16:29 +0000
commit52e1cb5ebf5e5a8cd5d3d9673b540b0c0dfe20df (patch)
tree078676a210b97f20bbebc123cfe028728a29a04e /perl.h
parent51dd5992be029393cb3f221313a1a6ec2a76c21a (diff)
downloadperl-52e1cb5ebf5e5a8cd5d3d9673b540b0c0dfe20df.tar.gz
AIX patch (including Configure support for {sched,pthread}_yield,
pthread initial detach state, renaming perl_thread to perl_os_thread and struct thread to struct perl_thread): Subject: Re: _54 on AIX p4raw-id: //depot/perl@290
Diffstat (limited to 'perl.h')
-rw-r--r--perl.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/perl.h b/perl.h
index b4e886552b..ddeff99158 100644
--- a/perl.h
+++ b/perl.h
@@ -1058,7 +1058,7 @@ union any {
};
#ifdef USE_THREADS
-#define ARGSproto struct thread *thr
+#define ARGSproto struct perl_thread *thr
#else
#define ARGSproto void
#endif /* USE_THREADS */
@@ -1362,18 +1362,18 @@ int runops_debug _((void));
/* global state */
EXT PerlInterpreter * curinterp; /* currently running interpreter */
#ifdef USE_THREADS
-EXT perl_key thr_key; /* For per-thread struct thread ptr */
+EXT perl_key thr_key; /* For per-thread struct perl_thread* */
EXT perl_mutex sv_mutex; /* Mutex for allocating SVs in sv.c */
EXT perl_mutex malloc_mutex; /* Mutex for malloc */
EXT perl_mutex eval_mutex; /* Mutex for doeval */
EXT perl_cond eval_cond; /* Condition variable for doeval */
-EXT struct thread * eval_owner; /* Owner thread for doeval */
+EXT struct perl_thread * eval_owner; /* Owner thread for doeval */
EXT int nthreads; /* Number of threads currently */
EXT perl_mutex threads_mutex; /* Mutex for nthreads and thread list */
EXT perl_cond nthreads_cond; /* Condition variable for nthreads */
EXT char * threadsv_names INIT(THREADSV_NAMES);
#ifdef FAKE_THREADS
-EXT struct thread * thr; /* Currently executing (fake) thread */
+EXT struct perl_thread * thr; /* Currently executing (fake) thread */
#endif
#endif /* USE_THREADS */
@@ -1959,7 +1959,7 @@ IEXT SV * Imess_sv;
#ifdef USE_THREADS
/* threads stuff */
-IEXT SV * Ithrsv; /* holds struct thread for main thread */
+IEXT SV * Ithrsv; /* holds struct perl_thread for main thread */
#endif /* USE_THREADS */
#undef IEXT